@@ -31,6 +31,8 @@
 #' \item \code{"cor_auto"} --- Uses \code{\link[qgraph]{cor_auto}} to compute correlations.
 #' Arguments can be passed along to the function
 #'
+#' \item \code{"cosine"} --- Uses \code{\link[EGAnet]{cosine}} to compute cosine similarity
+#'
 #' \item \code{"pearson"} --- Pearson's correlation is computed for all
 #' variables regardless of categories
 #'
@@ -227,10 +229,10 @@
 #'
 #' @export
 # EGA ----
-# Updated 24.10.2023
+# Updated 21.09.2024
 EGA <- function (
     data, n = NULL,
-    corr = c("auto", "cor_auto", "pearson", "spearman"),
+    corr = c("auto", "cor_auto", "cosine", "pearson", "spearman"),
     na.data = c("pairwise", "listwise"),
     model = c("BGGM", "glasso", "TMFG"),
     algorithm = c("leiden", "louvain", "walktrap"),
