@@ -86,7 +86,7 @@
 #' @export
 #'
 # Network Loadings ----
-# Updated 12.08.2024
+# Updated 26.09.2024
 net.loads <- function(
     A, wc, loading.method = c("original", "revised"),
     scaling = 2, rotation = NULL, ...
@@ -163,6 +163,9 @@ net.loads <- function(
       A, wc, nodes, node_names, communities, unique_communities
     )
 
+    # Store attributes
+    unstd_attributes <- attr(unstandardized, "community")
+
   }else{
 
     # Compute unstandardized loadings (absolute sums)
@@ -250,6 +253,11 @@ net.loads <- function(
     rotated = rotated
   )
 
+  # Add "community" attributes
+  if(loading.method == "revised"){
+    attr(results, "community") <- unstd_attributes
+  }
+
   # Add "methods" attributes
   attr(results, "methods") <- list(
     loading.method = loading.method, rotation = rotation
@@ -627,6 +635,24 @@ standardize <- function(unstandardized, loading.method, A, wc, scaling)
 
 }
 
+#' @noRd
+# Convert scale of revised loadings ----
+# Updated 26.09.2024
+scaling_conversion <- function(standardized, community, original_scaling, new_scaling)
+{
+
+  # Needs 'community' attribute from the unstandardized loadings
+  # This attribute is attached to the overall loading return when 'loading.method = "revised"'
+
+  # Compute change in scaling
+  delta <- community$community_sums^(1 / log(original_scaling * community$community_table)) /
+    community$community_sums^(1 / log(new_scaling * community$community_table))
+
+  # Return adjustment
+  return(t(t(standardized) * delta))
+
+}
+
 #' @noRd
 # Descending order ----
 # Updated 24.07.2023
